@@ -22,7 +22,6 @@
 
 #include <QAbstractListModel>
 #include <QQmlEngine>
-#include <QtQml>
 
 #include <Akonadi/FreeBusyManager>
 #include <akonadi/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
@@ -96,6 +95,12 @@ void CalendarPlugin::registerTypes(const char *uri)
     qRegisterMetaType<Akonadi::AgentFilterProxyModel *>();
     qRegisterMetaType<Akonadi::CollectionFilterProxyModel *>();
     qRegisterMetaType<QAction *>();
+
+    qmlRegisterSingletonType(QUrl(QStringLiteral("qrc:/qt/qml/org/kde/merkuro/calendar/DatePopupSingleton.qml")),
+                             "org.kde.merkuro",
+                             1,
+                             0,
+                             "DatePopupSingleton");
 }
 
 #include "moc_calendarplugin.cpp"
