@@ -7,6 +7,7 @@
 #include "merkuro_mail_debug.h"
 
 #include "mailkernel.h"
+#include "sortedcollectionproxymodel.h"
 #include <Akonadi/AgentManager>
 #include <Akonadi/ChangeRecorder>
 #include <Akonadi/CollectionCreateJob>
@@ -14,6 +15,7 @@
 #include <Akonadi/CollectionPropertiesDialog>
 #include <Akonadi/EntityMimeTypeFilterModel>
 #include <Akonadi/EntityTreeModel>
+#include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/ItemMoveJob>
 #include <Akonadi/MessageModel>
@@ -24,6 +26,7 @@
 #include <KConfigGroup>
 #include <KDescendantsProxyModel>
 #include <KLocalizedString>
+#include <KMbox/MBox>
 #include <KMime/Message>
 #include <MailCommon/EntityCollectionOrderProxyModel>
 #include <MailCommon/FolderCollectionMonitor>
@@ -31,7 +34,6 @@
 #include <QApplication>
 #include <QLoggingCategory>
 #include <QPointer>
-#include <sortedcollectionproxymodel.h>
 
 MailManager::MailManager(QObject *parent)
     : QObject(parent)
@@ -77,14 +79,14 @@ MailManager::MailManager(QObject *parent)
     connect(m_collectionSelectionModel, &QItemSelectionModel::selectionChanged, this, [this](const QItemSelection &selected, const QItemSelection &deselected) {
         Q_UNUSED(deselected)
         const auto indexes = selected.indexes();
-        if (indexes.count()) {
+        if (!indexes.isEmpty()) {
             QString name;
             QModelIndex index = indexes[0];
             while (index.isValid()) {
                 if (name.isEmpty()) {
                     name = index.data(Qt::DisplayRole).toString();
                 } else {
-                    name = index.data(Qt::DisplayRole).toString() + QLatin1String(" / ") + name;
+                    name = index.data(Qt::DisplayRole).toString() + QLatin1StringView(" / ") + name;
                 }
                 index = index.parent();
             }
@@ -243,4 +245,36 @@ QString MailManager::resourceIdentifier(const QModelIndex &index)
     return collection.resource();
 }
 
+void MailManager::saveMail(const QUrl &fileUrl, const Akonadi::Item &item)
+{
+    const auto filename = fileUrl.toLocalFile();
+
+    auto job = new Akonadi::ItemFetchJob(item);
+    job->fetchScope().fetchFullPayload();
+    connect(job, &Akonadi::ItemFetchJob::result, this, [this, filename](KJob *job) {
+        const auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+        const auto items = fetchJob->items();
+        if (items.isEmpty()) {
+            qWarning() << "Error occurred: empty fetch job";
+            return;
+        }
+        const auto item = items.at(0);
+        if (!item.hasPayload()) {
+            qCCritical(merkuro_MAIL_LOG) << "Error occured: error parsing mail";
+            return;
+        }
+
+        const auto message = item.payload<KMime::Message::Ptr>();
+        KMBox::MBox mbox;
+        if (!mbox.load(filename)) {
+            qCWarning(merkuro_MAIL_LOG) << "Error occured: error creating file";
+        }
+        mbox.appendMessage(message);
+
+        if (!mbox.save()) {
+            qCWarning(merkuro_MAIL_LOG) << "Error occured: error saving mail";
+        }
+    });
+}
+
 #include "moc_mailmanager.cpp"
